Classes et Fonctions
====================

Cette section documente les classes et fonctions définies pour aider à la
rédaction des énoncés et corrigés d'exercices.

Les deux premières parties (classes et outils) documentent le code de manière plutôt linéaire ; la troisième (exemples) présentent des exemples d'utilisation de ces classes et outils.

Les premières parties répondent à la question « Que fait la méthode :func:`tsointsoin` de la classe :class:`Tagada` » ; la dernière répond à la question « Comment manipuler des fractions/polynômes/équations/etc. ? ».

.. toctree::
    :maxdepth: 2

    pyromaths.classes
    pyromaths.outils
    pyromaths.exemples
